@@ -6,7 +6,7 @@ use Mojo::UserAgent;
 use Mojo::Promise;
 use Mojo::IOLoop;
 
-our $VERSION = '1.00';
+our $VERSION = '2.00';
 
 # Todo:
 # - Better test tracking API support
@@ -55,6 +55,8 @@ sub register {
   # Set app to server
   $plugin->ua->server->app($mojo);
 
+  state $script = $plugin_param->{script} ? $plugin_param->{script} : 'matomo';
+
   # Add 'piwik_tag' helper
   $mojo->helper(
     piwik_tag => sub {
@@ -112,7 +114,7 @@ sub register {
         };
 
         return b('<script src="' . $c->url_for('piwik_track_script')->to_abs . '"></script>' .
-                   "<script src=\"$prot://${url}piwik.js\" async defer></script>");
+                   "<script src=\"$prot://${url}${script}.js\" async defer></script>");
       }
 
       # Render opt-out tag
@@ -146,11 +148,11 @@ sub register {
 <script type="text/javascript">var _paq=window._paq=window._paq||[];
 _paq.push(['trackPageView']);_paq.push(['enableLinkTracking']);
 (function(){var u='http'+((document.location.protocol=='https:')?'s':'')+'://$url';
-_paq.push(['setTrackerUrl',u+'piwik.php']);_paq.push(['setSiteId',${site_id}]);
+_paq.push(['setTrackerUrl',u+'${script}.php']);_paq.push(['setSiteId',${site_id}]);
 var d=document,g=d.createElement('script'),s=d.getElementsByTagName('script')[0];
-g.type='text/javascript';g.async=true; g.src=u+'piwik.js'; s.parentNode.insertBefore(g,s);
+g.type='text/javascript';g.async=true; g.src=u+'${script}.js'; s.parentNode.insertBefore(g,s);
 })();$append</script>
-<noscript><img src="${prot}://${url}piwik.php?idSite=${site_id}&amp;rec=1" alt="" style="border:0"/></noscript>
+<noscript><img src="${prot}://${url}${script}.php?idSite=${site_id}&amp;rec=1" alt="" style="border:0"/></noscript>
 SCRIPTTAG
     });
 
@@ -189,7 +191,7 @@ SCRIPTTAG
             return $c->render(
               format => 'js',
               text => 'var _paq=window._paq=window._paq||[];' .
-                "_paq.push(['setTrackerUrl','$prot://${url}piwik.php']);" .
+                "_paq.push(['setTrackerUrl','$prot://${url}${script}.php']);" .
                 "_paq.push(['setSiteId',$site_id]);" .
                 q!_paq.push(['trackPageView']);! .
                 q!_paq.push(['enableLinkTracking']);! .
@@ -213,6 +215,8 @@ SCRIPTTAG
       # Get piwik url
       my $url = delete($param->{url}) || $plugin_param->{url};
 
+      my $send_image = delete($param->{send_image})  || '0';
+
       # TODO:
       #   Simplify and deprecate secure parameter
       if (!defined $param->{secure} && index($url, '/') != 0) {
@@ -241,19 +245,20 @@ SCRIPTTAG
       # Tracking API
       if (lc $method eq 'track') {
 
-        $url->path('piwik.php');
+        $url->path($script.'.php');
 
         # Request Headers
         my $header = $c->req->headers;
 
         # Set default values
         for ($param)  {
-          $_->{ua}     //= $header->user_agent if $header->user_agent;
-          $_->{urlref} //= $header->referrer   if $header->referrer;
-          $_->{rand}     = int(rand(10_000));
-          $_->{rec}      = 1;
-          $_->{apiv}     = 1;
-          $_->{url}      = delete $_->{action_url} || $c->url_for->to_abs;
+          $_->{ua}       //= $header->user_agent if $header->user_agent;
+          $_->{urlref}   //= $header->referrer   if $header->referrer;
+          $_->{rand}       = int(rand(10_000));
+          $_->{rec}        = 1;
+          $_->{apiv}       = 1;
+          $_->{url}        = delete $_->{action_url} || $c->url_for->to_abs;
+          $_->{send_image} = $send_image;
 
           # Todo: maybe make optional with parameter
           # $_->{_id} = rand ...
@@ -269,7 +274,6 @@ SCRIPTTAG
           return;
         };
 
-
         # Resolution
         if ($param->{res} && ref $param->{res}) {
           $param->{res} = join 'x', @{$param->{res}}[0, 1];
@@ -605,6 +609,12 @@ C<append> - Additional tracking code, that is appended to the code
 generated by L</piwik_tag> and the C<track_script> of the piwik shortcut.
 B<Experimental!>
 
+=item
+
+C<script> - The name of the tracking script. Defaults to C<matomo>
+(ending with C<.js> or C<.php>), but was C<piwik> before.
+
+
 =back
 
 All parameters can be set either as part of the configuration
@@ -744,6 +754,8 @@ C<dnt> - Override the Do-Not-Track setting, in rare cases, this is required.
 
 =back
 
+C<send_image> is set to C<0> by default, but can be overwritten.
+
 C<idSite> is an alias of C<site_id> and C<idsite> and defaults to the id
 of the plugin registration.
 Some parameters are allowed to be array references instead of string values,
@@ -861,14 +873,14 @@ L<Mojolicious>.
 Please make sure you are using Matomo (Piwik) in compliance to the law.
 For german users,
 L<this information|https://www.datenschutzzentrum.de/uploads/projekte/verbraucherdatenschutz/20110315-webanalyse-piwik.pdf>
-(last accessed on 2021-01-19)
+(last accessed on 2023-07-25)
 may help you to design your service correctly.
 You may need to inform your users about your usage of
 Piwik, especially if you are located in the European Union.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2021, L<Nils Diewald|https://nils-diewald.de/>.
+Copyright (C) 2012-2023, L<Nils Diewald|https://nils-diewald.de/>.
 
 This program is free software, you can redistribute it and/or
 modify it under the terms of the Artistic License version 2.0.
